@@ -29,15 +29,15 @@
 #define HAVE_ERRNO_H 1
 #define HAVE_SYSEXITS_H 1
 #define C_STACK_GROWS_DOWNWARD 1
-#ifndef __FreeBSD__
+#if !defined(__FreeBSD__) && !defined(__DragonFly__)
 # define C_USE_STD_FEATURE_MACROS
 #endif
 #define C_CHICKEN_PROGRAM "chicken"
 #ifndef C_INSTALL_CC
-# define C_INSTALL_CC "cc"
+# define C_INSTALL_CC "gcc"
 #endif
 #ifndef C_INSTALL_CXX
-# define C_INSTALL_CXX "c++"
+# define C_INSTALL_CXX "g++"
 #endif
 #ifndef C_INSTALL_POSTINSTALL_PROGRAM
 # define C_INSTALL_POSTINSTALL_PROGRAM "true"
@@ -46,34 +46,34 @@
 # define C_INSTALL_RC_COMPILER ""
 #endif
 #ifndef C_INSTALL_CFLAGS
-# define C_INSTALL_CFLAGS "-DHAVE_CHICKEN_CONFIG_H -O2 -pipe  "
+# define C_INSTALL_CFLAGS "-fno-strict-aliasing -fwrapv -DHAVE_CHICKEN_CONFIG_H -DC_ENABLE_PTABLES -Os -fomit-frame-pointer"
 #endif
 #ifndef C_INSTALL_LDFLAGS
 # define C_INSTALL_LDFLAGS " "
 #endif
 #ifndef C_INSTALL_PREFIX
-# define C_INSTALL_PREFIX "/usr/local"
+# define C_INSTALL_PREFIX "/usr/pkg"
 #endif
 #ifndef C_INSTALL_SHARE_HOME
-# define C_INSTALL_SHARE_HOME "/usr/local/share/chicken"
+# define C_INSTALL_SHARE_HOME "/usr/pkg/share/chicken"
 #endif
 #ifndef C_INSTALL_BIN_HOME
-# define C_INSTALL_BIN_HOME "/usr/local/bin"
+# define C_INSTALL_BIN_HOME "/usr/pkg/bin"
 #endif
 #ifndef C_INSTALL_EGG_HOME
-# define C_INSTALL_EGG_HOME "/usr/local/lib/chicken/8"
+# define C_INSTALL_EGG_HOME "/usr/pkg/lib/chicken/8"
 #endif
 #ifndef C_INSTALL_LIB_HOME
-# define C_INSTALL_LIB_HOME "/usr/local/lib"
+# define C_INSTALL_LIB_HOME "/usr/pkg/lib"
 #endif
 #ifndef C_INSTALL_LIB_NAME
 # define C_INSTALL_LIB_NAME "chicken"
 #endif
 #ifndef C_INSTALL_STATIC_LIB_HOME
-# define C_INSTALL_STATIC_LIB_HOME "/usr/local/lib"
+# define C_INSTALL_STATIC_LIB_HOME "/usr/pkg/lib"
 #endif
 #ifndef C_INSTALL_INCLUDE_HOME
-# define C_INSTALL_INCLUDE_HOME "/usr/local/include/chicken"
+# define C_INSTALL_INCLUDE_HOME "/usr/pkg/include/chicken"
 #endif
 #ifndef C_INSTALL_MORE_LIBS
 # define C_INSTALL_MORE_LIBS "-lm -lpthread"
@@ -94,16 +94,16 @@
 # define C_TARGET_MORE_STATIC_LIBS "-lm -lpthread"
 #endif
 #ifndef C_TARGET_CC
-# define C_TARGET_CC "cc"
+# define C_TARGET_CC "gcc"
 #endif
 #ifndef C_TARGET_CXX
-# define C_TARGET_CXX "c++"
+# define C_TARGET_CXX "g++"
 #endif
 #ifndef C_TARGET_RC_COMPILER
 # define C_TARGET_RC_COMPILER ""
 #endif
 #ifndef C_TARGET_CFLAGS
-# define C_TARGET_CFLAGS "-DHAVE_CHICKEN_CONFIG_H -O2 -pipe  "
+# define C_TARGET_CFLAGS "-fno-strict-aliasing -fwrapv -DHAVE_CHICKEN_CONFIG_H -DC_ENABLE_PTABLES -Os -fomit-frame-pointer"
 #endif
 #ifndef C_TARGET_LDFLAGS
 # define C_TARGET_LDFLAGS " "
@@ -115,28 +115,28 @@
 # define C_CROSS_CHICKEN 0
 #endif
 #ifndef C_TARGET_PREFIX
-# define C_TARGET_PREFIX "/usr/local"
+# define C_TARGET_PREFIX "/usr/pkg"
 #endif
 #ifndef C_TARGET_BIN_HOME
-# define C_TARGET_BIN_HOME "/usr/local/bin"
+# define C_TARGET_BIN_HOME "/usr/pkg/bin"
 #endif
 #ifndef C_TARGET_LIB_HOME
-# define C_TARGET_LIB_HOME "/usr/local/lib"
+# define C_TARGET_LIB_HOME "/usr/pkg/lib"
 #endif
 #ifndef C_TARGET_LIB_NAME
 # define C_TARGET_LIB_NAME "chicken"
 #endif
 #ifndef C_TARGET_RUN_LIB_HOME
-# define C_TARGET_RUN_LIB_HOME "/usr/local/lib"
+# define C_TARGET_RUN_LIB_HOME "/usr/pkg/lib"
 #endif
 #ifndef C_TARGET_SHARE_HOME
-# define C_TARGET_SHARE_HOME "/usr/local/share"
+# define C_TARGET_SHARE_HOME "/usr/pkg/share"
 #endif
 #ifndef C_TARGET_INCLUDE_HOME
-# define C_TARGET_INCLUDE_HOME "/usr/local/include/chicken"
+# define C_TARGET_INCLUDE_HOME "/usr/pkg/include/chicken"
 #endif
 #ifndef C_TARGET_STATIC_LIB_HOME
-# define C_TARGET_STATIC_LIB_HOME "/usr/local/lib"
+# define C_TARGET_STATIC_LIB_HOME "/usr/pkg/lib"
 #endif
 #ifndef C_CHICKEN_PROGRAM
 # define C_CHICKEN_PROGRAM "chicken"
@@ -166,6 +166,6 @@
 # define C_BINARY_VERSION 8
 #endif
 #ifndef C_USES_SONAME
-# define C_USES_SONAME 0
+# define C_USES_SONAME 1
 #endif
 /* END OF FILE */
